Stan Math Library: stan/math/prim/scal/meta/size_of.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces | Functions
size_of.hpp File Reference
`#include <stan/math/prim/scal/meta/is_vector.hpp>`
`#include <cstddef>`

Go to the source code of this file.

## Classes
struct | stan::size_of_helper< T, is_vec >
struct | stan::size_of_helper< T, true >

## Namespaces
| stan

## Functions
template<typename T >
size_t | stan::size_of (const T &x)

[ Stan Home Page ] © 2011–2016, Stan Development Team.